@@ -5,12 +5,11 @@ from emora_stdm import DialogueFlow
 
 school = DialogueFlow('_local_start')
 school.knowledge_base().load_json_file(PATHDIR.replace('__***__','_common.json'))
-school.knowledge_base().load_json_file(PATHDIR.replace('__***__','school.json'))
 school.add_system_transition('_local_start', 'start', '')
 
 system = {
     'state': 'start',
-    'enter': '#GATE #GCOM(school) #GOAL(school) #IF($life_in=True)',
+    'enter': '#GATE #GCOM(school) #GOAL(school) #IF($life_in=True) #SET($life_started=True)',
 
     '#DEFAULT':{
         'state': 'default_start',
@@ -23,7 +22,15 @@ system = {
     '#GSRET(default_start) #GATE':{
         'state': 'ask_user_student',
 
-        '[{#AGREE,[!-not,{correct,true,right}],[!i am,-not],[!-not,[i,#LEM(take),#LEM(class,course)]]}]'
+        '{#AGREE,'
+        '['
+        '{'
+        '[!-not,{correct,true,right}],'
+        '[!i am,-not],'
+        '[!-not,[i,#LEM(take),#LEM(class,course)]]'
+        '}'
+        ']'
+        '}'
         '#SET($is_student=True)':{
             'state': 'user_is_student',
 
@@ -35,14 +42,14 @@ system = {
             '#GATE': {
                 'state': 'ask_user_like_school',
 
-                '[{#AGREE,[!-not,i {do,#EXP(like)}]}]'
+                '{#AGREE,[[!-not,i {do,#EXP(like)}]]}'
                 '#SET($likes_school=True)':{
 
                     '`That\'s great! What\'s your favorite subject?`'
                     '#GSRET(clubs_question)': {
                         'state': 'ask_user_like_subject',
 
-                        '-#NEGATION [$favorite_subject=#ONT(_school subject)]': {
+                        '[!-#NEGATION [$favorite_subject=#ONT(_school subject)]]': {
                             'score': 2.0,
                             'state': 'user_like_subject',
 
@@ -111,7 +118,7 @@ system = {
                                     }
                                 },
 
-                                '-#NEGATION [{club,organization,society}]': 'unknown_club',
+                                '[!-#NEGATION [{club,organization,society}]]': 'unknown_club',
 
                                 '[$club=#ONT(_school club)]':{
                                     'state': 'known_club',
@@ -204,30 +211,46 @@ system = {
             'state': 'user_not_student'
         },
 
-        '[#NOT(not),{college,university}]'
+        '[#NOT(not,graduate,graduated,finished,completed,done),{college,university}]'
         '#SET($is_student=True,$in_college=True)':{
             'state': 'user_is_student',
             'score': 1.1
         },
 
-        '[#NOT(not),{high school,high schooler}]'
+        '[#NOT(not,graduate,graduated,finished,completed,done),{high school,high schooler}]'
         '#SET($is_student=True,$in_high_school=True)': {
             'state': 'user_is_student',
             'score': 1.1
         },
 
-        '[#NOT(not),{middle school,middle schooler,[!{sixth,seventh,eighth} grader],[!{sixth,seventh,eighth} grade]}]'
+        '[#NOT(not,graduate,graduated,finished,completed,done),{middle school,middle schooler,[!{sixth,seventh,eighth} grader],[!{sixth,seventh,eighth} grade]}]'
         '#SET($is_student=True,$in_middle_school=True)': {
             'state': 'user_is_student',
             'score': 1.1
         },
 
-        '[#NOT(not),{elementary school,elementary schooler,[!{first,second,third,fourth,fifth} grader],[!{first,second,third,fourth,fifth} grade]}]'
+        '[#NOT(not,graduate,graduated,finished,completed,done),{elementary school,elementary schooler,[!{first,second,third,fourth,fifth} grader],[!{first,second,third,fourth,fifth} grade]}]'
         '#SET($is_student=True,$in_elementary_school=True)': {
             'state': 'user_is_student',
             'score': 1.1
         },
 
+        '[#NOT(not),{am,just},{graduated,graduating}]':{
+            'state': 'graduating',
+            'score': 1.1,
+
+            '`Well, congratulations! Finishing school is something you should be really proud of! `': {
+                'state': 'graduating_r',
+
+                '[{thank you,thanks}]': {
+
+                    '`You\'re welcome! `': 'exit'
+                },
+
+                '#UNX': 'exit'
+            }
+        },
+
         '#UNX(Okay)': {
             'score': 0.8,
             'state': 'exit'
