@@ -176,7 +176,9 @@ class DialogueFlow:
         t2 = time()
         if debugging:
             print('System turn in {:.5f}'.format(t2-t1))
-        return  ' '.join(responses)
+        full_response = ' '.join(responses)
+        self.vars()['__selected_response__'] = full_response
+        return full_response
 
     def user_turn(self, natural_language, debugging=False):
         """
@@ -1047,6 +1049,9 @@ class DialogueFlow:
         for pre, post in rules_dict.items():
             self.update_rules().add(pre, post)
 
+    def macros(self):
+        return self._macros
+
     def add_goal(self, id_string, return_state=None, return_phrase=None, doom_counter=None):
         goal = {
             'id': id_string,
